using System;
using System.Collections.Generic;
using System.IO;
using UnityEngine;
using UnityEngine.Events;

namespace Mod
{
    public class Mod
    {
        public static void Main()
        {
			CategoryBuilder.Create("World War II", "A category for world war era items.", ModAPI.LoadSprite("category.png"));
            //German Infantry
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
                    NameOverride = "German Infantry -CWM", //new item name with a suffix to assure it is globally unique
					NameToOrderByOverride = "a",
                    DescriptionOverride = "A German soldier.", //new item description
                    CategoryOverride = ModAPI.FindCategory("World War II"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("gi_View.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        //load textures for each layer (see Human textures folder in this repository)
                        var skin = ModAPI.LoadTexture("g_infantry.png");
                        var flesh = ModAPI.LoadTexture("flesh.png");
                        var bone = ModAPI.LoadTexture("bone.png");

                        //get person
                        var person = Instance.GetComponent<PersonBehaviour>();

                        //use the helper function to set each texture
                        //parameters are as follows: 
                        //  skin texture, flesh texture, bone texture, sprite scale
                        //you can pass "null" to fall back to the original texture
                        person.SetBodyTextures(skin, flesh, bone, 1);

                        //change procedural damage colours if they interfere with your texture (rgb 0-255)
                        person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
                        person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
                        person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
                        person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
                        person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
                    }
                }
            );
            //German Medic
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
                    NameOverride = "German Medic -CWM", //new item name with a suffix to assure it is globally unique
                    DescriptionOverride = "A German medic.", //new item description
					NameToOrderByOverride = "a",
                    CategoryOverride = ModAPI.FindCategory("World War II"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("gm_View.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        //load textures for each layer (see Human textures folder in this repository)
                        var skin = ModAPI.LoadTexture("g_medic.png");
                        var flesh = ModAPI.LoadTexture("flesh.png");
                        var bone = ModAPI.LoadTexture("bone.png");

                        //get person
                        var person = Instance.GetComponent<PersonBehaviour>();

                        //use the helper function to set each texture
                        //parameters are as follows: 
                        //  skin texture, flesh texture, bone texture, sprite scale
                        //you can pass "null" to fall back to the original texture
                        person.SetBodyTextures(skin, flesh, bone, 1);

                        //change procedural damage colours if they interfere with your texture (rgb 0-255)
                        person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
                        person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
                        person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
                        person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
                        person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
                    }
                }
            );
            //German Tanker
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
                    NameOverride = "German Tanker -CWM", //new item name with a suffix to assure it is globally unique
					NameToOrderByOverride = "a",
                    DescriptionOverride = "A German tanker.", //new item description
                    CategoryOverride = ModAPI.FindCategory("World War II"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("gt_View.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        //load textures for each layer (see Human textures folder in this repository)
                        var skin = ModAPI.LoadTexture("g_tanker.png");
                        var flesh = ModAPI.LoadTexture("flesh.png");
                        var bone = ModAPI.LoadTexture("bone.png");

                        //get person
                        var person = Instance.GetComponent<PersonBehaviour>();

                        //use the helper function to set each texture
                        //parameters are as follows: 
                        //  skin texture, flesh texture, bone texture, sprite scale
                        //you can pass "null" to fall back to the original texture
                        person.SetBodyTextures(skin, flesh, bone, 1);

                        //change procedural damage colours if they interfere with your texture (rgb 0-255)
                        person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
                        person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
                        person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
                        person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
                        person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
                    }
                }
            );
            //Japanese Infantry
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
                    NameOverride = "Japanese Infantry -CWM", //new item name with a suffix to assure it is globally unique
					NameToOrderByOverride = "b",
                    DescriptionOverride = "A Japanese soldier.", //new item description
                    CategoryOverride = ModAPI.FindCategory("World War II"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("ji_View.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        //load textures for each layer (see Human textures folder in this repository)
                        var skin = ModAPI.LoadTexture("j_infantry.png");
                        var flesh = ModAPI.LoadTexture("flesh.png");
                        var bone = ModAPI.LoadTexture("bone.png");

                        //get person
                        var person = Instance.GetComponent<PersonBehaviour>();

                        //use the helper function to set each texture
                        //parameters are as follows: 
                        //  skin texture, flesh texture, bone texture, sprite scale
                        //you can pass "null" to fall back to the original texture
                        person.SetBodyTextures(skin, flesh, bone, 1);

                        //change procedural damage colours if they interfere with your texture (rgb 0-255)
                        person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
                        person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
                        person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
                        person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
                        person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
                    }
                }
            );
            //Japanese Medic
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
                    NameOverride = "Japanese Medic -CWM", //new item name with a suffix to assure it is globally unique
					NameToOrderByOverride = "b",
                    DescriptionOverride = "A Japanese medic.", //new item description
                    CategoryOverride = ModAPI.FindCategory("World War II"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("jm_View.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        //load textures for each layer (see Human textures folder in this repository)
                        var skin = ModAPI.LoadTexture("j_medic.png");
                        var flesh = ModAPI.LoadTexture("flesh.png");
                        var bone = ModAPI.LoadTexture("bone.png");

                        //get person
                        var person = Instance.GetComponent<PersonBehaviour>();

                        //use the helper function to set each texture
                        //parameters are as follows: 
                        //  skin texture, flesh texture, bone texture, sprite scale
                        //you can pass "null" to fall back to the original texture
                        person.SetBodyTextures(skin, flesh, bone, 1);

                        //change procedural damage colours if they interfere with your texture (rgb 0-255)
                        person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
                        person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
                        person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
                        person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
                        person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
                    }
                }
            );
            //Japanese Tanker
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
                    NameOverride = "Japanese Tanker -CWM", //new item name with a suffix to assure it is globally unique
					NameToOrderByOverride = "b",
                    DescriptionOverride = "A Japanese tanker.", //new item description
                    CategoryOverride = ModAPI.FindCategory("World War II"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("jt_View.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        //load textures for each layer (see Human textures folder in this repository)
                        var skin = ModAPI.LoadTexture("j_tanker.png");
                        var flesh = ModAPI.LoadTexture("flesh.png");
                        var bone = ModAPI.LoadTexture("bone.png");

                        //get person
                        var person = Instance.GetComponent<PersonBehaviour>();

                        //use the helper function to set each texture
                        //parameters are as follows: 
                        //  skin texture, flesh texture, bone texture, sprite scale
                        //you can pass "null" to fall back to the original texture
                        person.SetBodyTextures(skin, flesh, bone, 1);

                        //change procedural damage colours if they interfere with your texture (rgb 0-255)
                        person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
                        person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
                        person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
                        person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
                        person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
                    }
                }
            );
            //American Infantry
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
                    NameOverride = "American Infantry -CWM", //new item name with a suffix to assure it is globally unique
					NameToOrderByOverride = "c",
                    DescriptionOverride = "An American soldier.", //new item description
                    CategoryOverride = ModAPI.FindCategory("World War II"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("ai_View.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        //load textures for each layer (see Human textures folder in this repository)
                        var skin = ModAPI.LoadTexture("a_infantry.png");
                        var flesh = ModAPI.LoadTexture("flesh.png");
                        var bone = ModAPI.LoadTexture("bone.png");

                        //get person
                        var person = Instance.GetComponent<PersonBehaviour>();

                        //use the helper function to set each texture
                        //parameters are as follows: 
                        //  skin texture, flesh texture, bone texture, sprite scale
                        //you can pass "null" to fall back to the original texture
                        person.SetBodyTextures(skin, flesh, bone, 1);

                        //change procedural damage colours if they interfere with your texture (rgb 0-255)
                        person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
                        person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
                        person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
                        person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
                        person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
                    }
                }
            );
            //American Medic
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
                    NameOverride = "American Medic -CWM", //new item name with a suffix to assure it is globally unique
					NameToOrderByOverride = "c",
                    DescriptionOverride = "An American medic.", //new item description
                    CategoryOverride = ModAPI.FindCategory("World War II"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("am_View.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        //load textures for each layer (see Human textures folder in this repository)
                        var skin = ModAPI.LoadTexture("a_medic.png");
                        var flesh = ModAPI.LoadTexture("flesh.png");
                        var bone = ModAPI.LoadTexture("bone.png");

                        //get person
                        var person = Instance.GetComponent<PersonBehaviour>();

                        //use the helper function to set each texture
                        //parameters are as follows: 
                        //  skin texture, flesh texture, bone texture, sprite scale
                        //you can pass "null" to fall back to the original texture
                        person.SetBodyTextures(skin, flesh, bone, 1);

                        //change procedural damage colours if they interfere with your texture (rgb 0-255)
                        person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
                        person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
                        person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
                        person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
                        person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
                    }
                }
            );
            //American Tanker
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
                    NameOverride = "American Tanker -CWM", //new item name with a suffix to assure it is globally unique
					NameToOrderByOverride = "c",
                    DescriptionOverride = "An American tanker.", //new item description
                    CategoryOverride = ModAPI.FindCategory("World War II"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("at_View.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        //load textures for each layer (see Human textures folder in this repository)
                        var skin = ModAPI.LoadTexture("a_tanker.png");
                        var flesh = ModAPI.LoadTexture("flesh.png");
                        var bone = ModAPI.LoadTexture("bone.png");

                        //get person
                        var person = Instance.GetComponent<PersonBehaviour>();

                        //use the helper function to set each texture
                        //parameters are as follows: 
                        //  skin texture, flesh texture, bone texture, sprite scale
                        //you can pass "null" to fall back to the original texture
                        person.SetBodyTextures(skin, flesh, bone, 1);

                        //change procedural damage colours if they interfere with your texture (rgb 0-255)
                        person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
                        person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
                        person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
                        person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
                        person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
                    }
                }
            );
            //British Infantry
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
                    NameOverride = "British Infantry -CWM", //new item name with a suffix to assure it is globally unique
					NameToOrderByOverride = "d",
                    DescriptionOverride = "A British soldier.", //new item description
                    CategoryOverride = ModAPI.FindCategory("World War II"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("bi_View.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        //load textures for each layer (see Human textures folder in this repository)
                        var skin = ModAPI.LoadTexture("b_infantry.png");
                        var flesh = ModAPI.LoadTexture("flesh.png");
                        var bone = ModAPI.LoadTexture("bone.png");

                        //get person
                        var person = Instance.GetComponent<PersonBehaviour>();

                        //use the helper function to set each texture
                        //parameters are as follows: 
                        //  skin texture, flesh texture, bone texture, sprite scale
                        //you can pass "null" to fall back to the original texture
                        person.SetBodyTextures(skin, flesh, bone, 1);

                        //change procedural damage colours if they interfere with your texture (rgb 0-255)
                        person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
                        person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
                        person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
                        person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
                        person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
                    }
                }
            );
            //British Medic
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
                    NameOverride = "British Medic -CWM", //new item name with a suffix to assure it is globally unique
					NameToOrderByOverride = "d",
                    DescriptionOverride = "A British medic.", //new item description
                    CategoryOverride = ModAPI.FindCategory("World War II"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("bm_View.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        //load textures for each layer (see Human textures folder in this repository)
                        var skin = ModAPI.LoadTexture("b_medic.png");
                        var flesh = ModAPI.LoadTexture("flesh.png");
                        var bone = ModAPI.LoadTexture("bone.png");

                        //get person
                        var person = Instance.GetComponent<PersonBehaviour>();

                        //use the helper function to set each texture
                        //parameters are as follows: 
                        //  skin texture, flesh texture, bone texture, sprite scale
                        //you can pass "null" to fall back to the original texture
                        person.SetBodyTextures(skin, flesh, bone, 1);

                        //change procedural damage colours if they interfere with your texture (rgb 0-255)
                        person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
                        person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
                        person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
                        person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
                        person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
                    }
                }
            );
            //British Tanker
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
                    NameOverride = "British Tanker -CWM", //new item name with a suffix to assure it is globally unique
					NameToOrderByOverride = "d",
                    DescriptionOverride = "A British tanker.", //new item description
                    CategoryOverride = ModAPI.FindCategory("World War II"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("bt_View.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        //load textures for each layer (see Human textures folder in this repository)
                        var skin = ModAPI.LoadTexture("b_tanker.png");
                        var flesh = ModAPI.LoadTexture("flesh.png");
                        var bone = ModAPI.LoadTexture("bone.png");

                        //get person
                        var person = Instance.GetComponent<PersonBehaviour>();

                        //use the helper function to set each texture
                        //parameters are as follows: 
                        //  skin texture, flesh texture, bone texture, sprite scale
                        //you can pass "null" to fall back to the original texture
                        person.SetBodyTextures(skin, flesh, bone, 1);

                        //change procedural damage colours if they interfere with your texture (rgb 0-255)
                        person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
                        person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
                        person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
                        person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
                        person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
                    }
                }
            );
			//Soviet Infantry
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
                    NameOverride = "Soviet Infantry -CWM", //new item name with a suffix to assure it is globally unique
					NameToOrderByOverride = "e",
                    DescriptionOverride = "A Soviet soldier.", //new item description
                    CategoryOverride = ModAPI.FindCategory("World War II"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("si_View.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        //load textures for each layer (see Human textures folder in this repository)
                        var skin = ModAPI.LoadTexture("r_infantry.png");
                        var flesh = ModAPI.LoadTexture("flesh.png");
                        var bone = ModAPI.LoadTexture("bone.png");

                        //get person
                        var person = Instance.GetComponent<PersonBehaviour>();

                        //use the helper function to set each texture
                        //parameters are as follows: 
                        //  skin texture, flesh texture, bone texture, sprite scale
                        //you can pass "null" to fall back to the original texture
                        person.SetBodyTextures(skin, flesh, bone, 1);

                        //change procedural damage colours if they interfere with your texture (rgb 0-255)
                        person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
                        person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
                        person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
                        person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
                        person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
                    }
                }
            );
			//Soviet Medic
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
                    NameOverride = "Soviet Medic -CWM", //new item name with a suffix to assure it is globally unique
					NameToOrderByOverride = "e",
                    DescriptionOverride = "A Soviet medic.", //new item description
                    CategoryOverride = ModAPI.FindCategory("World War II"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("sm_View.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        //load textures for each layer (see Human textures folder in this repository)
                        var skin = ModAPI.LoadTexture("r_medic.png");
                        var flesh = ModAPI.LoadTexture("flesh.png");
                        var bone = ModAPI.LoadTexture("bone.png");

                        //get person
                        var person = Instance.GetComponent<PersonBehaviour>();

                        //use the helper function to set each texture
                        //parameters are as follows: 
                        //  skin texture, flesh texture, bone texture, sprite scale
                        //you can pass "null" to fall back to the original texture
                        person.SetBodyTextures(skin, flesh, bone, 1);

                        //change procedural damage colours if they interfere with your texture (rgb 0-255)
                        person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
                        person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
                        person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
                        person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
                        person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
                    }
                }
            );
			//Soviet Tanker
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Human"), //item to derive from
                    NameOverride = "Soviet Tanker -CWM", //new item name with a suffix to assure it is globally unique
					NameToOrderByOverride = "e",
                    DescriptionOverride = "A Soviet tanker.", //new item description
                    CategoryOverride = ModAPI.FindCategory("World War II"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("st_View.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        //load textures for each layer (see Human textures folder in this repository)
                        var skin = ModAPI.LoadTexture("r_tanker.png");
                        var flesh = ModAPI.LoadTexture("flesh.png");
                        var bone = ModAPI.LoadTexture("bone.png");

                        //get person
                        var person = Instance.GetComponent<PersonBehaviour>();

                        //use the helper function to set each texture
                        //parameters are as follows: 
                        //  skin texture, flesh texture, bone texture, sprite scale
                        //you can pass "null" to fall back to the original texture
                        person.SetBodyTextures(skin, flesh, bone, 1);

                        //change procedural damage colours if they interfere with your texture (rgb 0-255)
                        person.SetBruiseColor(86, 62, 130); //main bruise colour. purple-ish by default
                        person.SetSecondBruiseColor(154, 0, 7); //second bruise colour. red by default
                        person.SetThirdBruiseColor(207, 206, 120); // third bruise colour. light yellow by default
                        person.SetRottenColour(202, 199, 104); // rotten/zombie colour. light yellow/green by default
                        person.SetBloodColour(108, 0, 4); // blood colour. dark red by default. note that this does not change decal nor particle effect colours. it only affects the procedural blood color which may or may not be rendered
                    }
                }
            );
			//German Gasmask
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Soap"),
                    NameOverride = "German Gasmask -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A German Gasmask.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("g_gasmask_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("g_gasmask.png");
						Instance.GetComponent<PhysicalBehaviour>().Properties = ModAPI.FindPhysicalProperties("Rubber");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 6f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//Flammenwerfer Fueltank
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Red Barrel"),
                    NameOverride = "Flammenwerfer Fueltank -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A small tank containing fuel.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("ffuel_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("ffuel.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 10f;
                        armor.armorPiece = "UpperBody";
                        armor.armorTier = 1;
                    }
                }
            );
			//Flammenwerfer 35
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Flamethrower"),
                    NameOverride = "Flammenwerfer 35 -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "A German Flamethrower.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("flammen_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("flammen.png");
						Instance.FixColliders();
                    }
                }
            );
			//Bayonet
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Knife"),
                    NameOverride = "Bayonet -CWM",
                    NameToOrderByOverride = "g",
                    DescriptionOverride = "A bayonet for rifles.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("bayonet_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("bayonet.png");
						Instance.FixColliders();
                    }
                }
            );
			//BC-41
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Knife"),
                    NameOverride = "BC-41 -CWM",
                    NameToOrderByOverride = "g",
                    DescriptionOverride = "A British combined knuckleduster and dagger.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("bc41_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("bc41.png");
						Instance.FixColliders();
                    }
                }
            );
			//NR-40
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Knife"),
                    NameOverride = "NR-40 -CWM",
                    NameToOrderByOverride = "g",
                    DescriptionOverride = "A Soviet combat knife.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("nr40_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("nr40.png");
						Instance.FixColliders();
                    }
                }
            );
			//Pipe Wrench
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Wrench"),
                    NameOverride = "Pipe Wrench -CWM",
                    NameToOrderByOverride = "g",
                    DescriptionOverride = "An ajustable wrench.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("m_wrench_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("m_wrench.png");
						Instance.FixColliders();
                    }
                }
            );
			//MPL-50
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "MPL-50 -CWM",
                    NameToOrderByOverride = "g",
                    DescriptionOverride = "A Soviet spade.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("mpl_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("mpl.png");
						Instance.FixColliders();
                    }
                }
            );
			//MP 40
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Submachine Gun"),
                    NameOverride = "MP 40 -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "A German submachine gun.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("mp40_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("mp40.png");
						Instance.FixColliders();
						var firearm = Instance.GetComponent<FirearmBehaviour>();
						firearm.AutomaticFireInterval = 0.099f;
                        firearm.ShotSounds = new AudioClip[]
                        {
                            ModAPI.LoadSound("mp40.wav")
                        };
                    }
                }
            );
			//M3
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Submachine Gun"),
                    NameOverride = "M3 -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "An American submachine gun.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("m3_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("m3.png");
						Instance.FixColliders();
                    }
                }
            );
			//M1921 Thompson
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("PPSH"),
                    NameOverride = "M1921 Thompson -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "An American submachine gun.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("thompson_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("thompson.png");
						Instance.FixColliders();
                    }
                }
            );
			//PPSh 41
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("PPSH"),
                    NameOverride = "PPSh 41 -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "A Soviet submachine gun.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("ppsh_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("ppsh.png");
						Instance.FixColliders();
						var firearm = Instance.GetComponent<FirearmBehaviour>();
                        firearm.ShotSounds = new AudioClip[]
                        {
                            ModAPI.LoadSound("ppsh.wav")
                        };
                    }
                }
            );
			//Beretta Model 38
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("PPSH"),
                    NameOverride = "Beretta Model 38 -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "An Italian submachine gun.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("beretta_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("beretta.png");
						Instance.FixColliders();
                    }
                }
            );
			//ZK-383
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("PPSH"),
                    NameOverride = "ZK-383 -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "A Czechoslovakian submachine gun.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("zk383_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("zk383.png");
						Instance.FixColliders();
						var firearm = Instance.GetComponent<FirearmBehaviour>();
						firearm.AutomaticFireInterval = 0.09f;
                        firearm.ShotSounds = new AudioClip[]
                        {
                            ModAPI.LoadSound("zk383.wav")
                        };
                    }
                }
            );
			//Ribeyrolles 1918
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("PPSH"),
                    NameOverride = "Ribeyrolles 1918 -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "A French assault rifle.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("ribeyrolles_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("ribeyrolles.png");
						Instance.FixColliders();
                    }
                }
            );
			//M2 Browning
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Light Machine Gun"),
                    NameOverride = "M2 Browning -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "An American heavy machine gun.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("m2b_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("m2b.png");
						Instance.FixColliders();
						var firearm = Instance.GetComponent<FirearmBehaviour>();

						firearm.InitialInaccuracy = 0.05f;
                    }
                }
            );
			//StG 44
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("PPSH"),
                    NameOverride = "StG 44 -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "A German assault rifle.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("stg44_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("stg44.png");
						Instance.FixColliders();
                    }
                }
            );
			//P08 Luger
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Pistol"),
                    NameOverride = "P08 Luger -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "A German semi-automatic pistol.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("p08_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("p08.png");
						Instance.FixColliders();
                          var firearm = Instance.GetComponent<FirearmBehaviour>();
                        firearm.ShotSounds = new AudioClip[]
                        {
                            ModAPI.LoadSound("p08.wav")
                        };
                    }
                }
            );
			//TT-33 Tokarev
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Glock 17"),
                    NameOverride = "TT-33 Tokarev -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "A Soviet semi-automatic pistol.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("tokarev_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("tokarev.png");
						Instance.FixColliders();
                          var firearm = Instance.GetComponent<FirearmBehaviour>();
                        firearm.ShotSounds = new AudioClip[]
                        {
                            ModAPI.LoadSound("m1911.wav")
                        };
                    }
                }
            );
			//Mauser C96
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Glock 17"),
                    NameOverride = "Mauser C96 -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "A German semi-automatic pistol.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("c96_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("c96.png");
						Instance.FixColliders();
                          var firearm = Instance.GetComponent<FirearmBehaviour>();
                        firearm.ShotSounds = new AudioClip[]
                        {
                            ModAPI.LoadSound("p08.wav")
                        };
                    }
                }
            );
			//M1911
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Glock 17"),
                    NameOverride = "M1911 -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "An American semi-automatic pistol.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("m1911_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("m1911.png");
						Instance.FixColliders();
                          var firearm = Instance.GetComponent<FirearmBehaviour>();
                        firearm.ShotSounds = new AudioClip[]
                        {
                            ModAPI.LoadSound("m1911.wav")
                        };
                    }
                }
            );
			//SVT-40
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                    NameOverride = "SVT-40 -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "A Soviet semi-automatic rifle.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("svt40_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("svt40.png");
						Instance.FixColliders();
                          var firearm = Instance.GetComponent<FirearmBehaviour>();
                        firearm.ShotSounds = new AudioClip[]
                        {
                            ModAPI.LoadSound("svt40.wav")
                        };
                    }
                }
            );
			//M1 Garand
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                    NameOverride = "M1 Garand -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "An American semi-automatic rifle.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("garand_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("garand.png");
						Instance.FixColliders();
                          var firearm = Instance.GetComponent<FirearmBehaviour>();
                        firearm.ShotSounds = new AudioClip[]
                        {
                            ModAPI.LoadSound("garand.wav")
                        };
                    }
                }
            );
			//Karabiner 98k
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                    NameOverride = "Karabiner 98k -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "A German bolt-action rifle.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("kara_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("kara.png");
						Instance.FixColliders();
                          var firearm = Instance.GetComponent<FirearmBehaviour>();
                        firearm.ShotSounds = new AudioClip[]
                        {
                            ModAPI.LoadSound("kara.wav")
                        };
                    }
                }
            );
			//Winchester Model 1897
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Shotgun"),
                    NameOverride = "Winchester Model 1897 -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "An American shotgun.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("winchester_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("winchester.png");
						Instance.FixColliders();
                          var firearm = Instance.GetComponent<FirearmBehaviour>();
                        firearm.ShotSounds = new AudioClip[]
                        {
                            ModAPI.LoadSound("winchester.wav")
                        };
                    }
                }
            );
			//Lee-Enfield
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("M1 Garand"),
                    NameOverride = "Lee-Enfield -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "A British bolt-action rifle.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("lee_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("lee.png");
						Instance.FixColliders();
                          var firearm = Instance.GetComponent<FirearmBehaviour>();
                        firearm.ShotSounds = new AudioClip[]
                        {
                            ModAPI.LoadSound("lee.wav")
                        };
                    }
                }
            );
			//Panzerschreck
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rocket Launcher"),
                    NameOverride = "Panzerschreck -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "A German anti-tank rocket launcher.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("pzshk_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("pzshk.png");
						Instance.FixColliders();
                    }
                }
            );
			//M1 Bazooka
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rocket Launcher"),
                    NameOverride = "M1 Bazooka -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "An American anti-tank rocket launcher.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("m1b_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("m1b.png");
						Instance.FixColliders();
                    }
                }
            );
			//No.36 Mk.I
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Handgrenade"),
                    NameOverride = "No.36 Mk.I Handgrenade -CWM",
                    NameToOrderByOverride = "i",
                    DescriptionOverride = "A British handgrenade.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("no36_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("no36.png");
						Instance.FixColliders();
                    }
                }
            );
			//Stielhandgranate
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Handgrenade"),
                    NameOverride = "Stielhandgranate -CWM",
                    NameToOrderByOverride = "i",
                    DescriptionOverride = "A German handgrenade.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("shg_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("shg.png");
						Instance.FixColliders();
                    }
                }
            );
			//Tellermine 43
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Dynamite"),
                    NameOverride = "Tellermine 43 -CWM",
                    NameToOrderByOverride = "i",
                    DescriptionOverride = "A German anti-tank mine.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("tellermine_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("tellermine.png");
						Instance.FixColliders();
						Instance.GetComponent<ExplosiveBehaviour>().ImpactForceThreshold = 2f;
                    }
                }
            );
			//Ammobox
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "Ammobox -CWM",
                    NameToOrderByOverride = "j",
                    DescriptionOverride = "A box for storing ammunition.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("ammobox_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("ammobox.png");
						Instance.FixColliders();
                    }
                }
            );
			//DKE 38
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Jukebox"),
                    NameOverride = "DKE 38 -CWM",
                    NameToOrderByOverride = "j",
                    DescriptionOverride = "A German radio.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("dke38_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("dke38.png");
						Instance.FixColliders();
                        Instance.GetComponent<PhysicalBehaviour>().InitialMass = 1.5f;
                        Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 1.5f;
                    }
                }
            );
			//MG 42
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Light Machine Gun"),
                    NameOverride = "MG 42 -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "A German general-purpose machine gun.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("mg42_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("mg42.png");
						Instance.FixColliders();
						var firearm = Instance.GetComponent<FirearmBehaviour>();

						firearm.AutomaticFireInterval = 0.05f;
						firearm.InitialInaccuracy = 0.05f;
                        firearm.ShotSounds = new AudioClip[]
                        {
                            ModAPI.LoadSound("mg42.wav")
                        };
                    }
                }
            );
			//MG 34
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Light Machine Gun"),
                    NameOverride = "MG 34 -CWM",
                    NameToOrderByOverride = "h",
                    DescriptionOverride = "A German general-purpose machine gun.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("mg34_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("mg34.png");
						Instance.FixColliders();
						var firearm = Instance.GetComponent<FirearmBehaviour>();

						firearm.AutomaticFireInterval = 0.1f;
						firearm.InitialInaccuracy = 0.05f;
                        firearm.ShotSounds = new AudioClip[]
                        {
                            ModAPI.LoadSound("mg42.wav")
                        };
                    }
                }
            );
			//M35 Helmet
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "M35 Helmet -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A German helmet.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("stahlhelm_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("stahlhelm.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 2f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//M35 Helmet (Medic)
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "M35 Helmet (Medic) -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A German helmet with medical markings.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("m_stahlhelm_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("m_stahlhelm.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 2f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//Mk.II Helmet
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "Mk.II Helmet -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A British helmet.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("mkii_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("mkii.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 2f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//Mk.II Helmet (Medic)
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "Mk.II Helmet (Medic) -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A British helmet with medical markings.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("m_mkii_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("m_mkii.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 2f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//M1 Helmet
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "M1 Helmet -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "An American helmet.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("m1_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("m1.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 2f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//M1 Helmet (Medic)
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "M1 Helmet (Medic) -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "An American helmet with medical markings.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("m_m1_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("m_m1.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 2f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//M1938 Tanker Helmet
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "M1938 Tanker Helmet -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "An American tanker helmet.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("a_tanker_cap_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("a_tanker_cap.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 2f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//SSh-40 Helmet
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "SSh-40 Helmet -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A Soviet helmet.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("ssh-40_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("ssh-40.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 2f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//SSh-40 Helmet (Medic)
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "SSh-40 Helmet (Medic) -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A Soviet helmet with medical markings.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("m_ssh-40_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("m_ssh-40.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();
                        armor.stabResistance = 2f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//TSh-4 Tanker Helmet
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Stick"),
                    NameOverride = "TSh-4 Tanker Helmet -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A Soviet tanker helmet.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("r_tanker_cap_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("r_tanker_cap.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 2f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//M1932 Helmet
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "M1932 Helmet -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A Japanese helmet.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("m1932_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("m1932.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 2f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//M1932 Helmet (Medic)
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "M1932 Helmet (Medic) -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A Japanese helmet with medical markings.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("m_m1932_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("m_m1932.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 2f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//Japanese Tanker Helmet
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Stick"),
                    NameOverride = "Japanese Tanker Helmet -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A Japanese tanker helmet.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("j_tanker_cap_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("j_tanker_cap.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 2f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//M15 Helmet
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"),
                    NameOverride = "M15 Helmet -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A French helmet.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("m15_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("m15.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 2f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//German Officer Cap
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Stick"),
                    NameOverride = "German Officer Cap -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A German officer cap.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("g_officer_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("g_officer_cap.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 0f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//M43 Field Cap
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Stick"),
                    NameOverride = "M43 Field Cap -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A German field cap.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("g_field_cap_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("g_field_cap.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 0f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//Japanese Field Cap
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Stick"),
                    NameOverride = "Japanese Field Cap -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A Japanese field cap.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("j_field_cap_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("j_field_cap.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 0f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//Cigarette Box
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Stick"),
                    NameOverride = "Cigarette Box -CWM",
                    NameToOrderByOverride = "j",
                    DescriptionOverride = "A box to keep all of your cigarettes in.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("ciggy_box_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("ciggy_box.png");
						Instance.FixColliders();
                    }
                }
            );
			//M38 Tanker Cap
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Stick"),
                    NameOverride = "M38 Tanker Cap -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A German tanker cap with a headset.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("g_tanker_cap_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("g_tanker_cap.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 0f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//B Officer Cap
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Stick"),
                    NameOverride = "British Officer Cap -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A British officer cap.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("b_officer_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("b_officer_cap.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 0f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//Soviet Officer Cap
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Stick"),
                    NameOverride = "Soviet Officer Cap -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A Soviet officer cap.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("s_officer_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("s_officer_cap.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 0f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//British Tanker Beret
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Stick"),
                    NameOverride = "British Tanker Beret -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A British tanker beret.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("b_tanker_beret_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("b_tanker_beret.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 0f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//Ushanka
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Stick"),
                    NameOverride = "Ushanka -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A Soviet fur cap.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("ushanka_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("ushanka.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 0f;
                        armor.armorPiece = "Head";
                        armor.armorTier = 0;
                    }
                }
            );
			//German Armband
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Stick"),
                    NameOverride = "German Armband -CWM",
                    NameToOrderByOverride = "f",
                    DescriptionOverride = "A WWII German armband. PURELY FOR HISTORICAL REENACTMENT.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("g_armband_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("g_armband.png");
						Instance.FixColliders();
                        ArmorBehaviour armor = Instance.AddComponent<ArmorBehaviour>();

                        armor.stabResistance = 0f;
                        armor.armorPiece = "UpperArm";
                        armor.armorTier = 0;
                    }
                }
            );
			//SC250
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("General Purpose Bomb"),
                    NameOverride = "SC250 -CWM",
                    NameToOrderByOverride = "i",
                    DescriptionOverride = "A German 250Kg Bomb.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("sc250_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("sc250.png");
						Instance.FixColliders();
                        Instance.GetComponent<ExplosiveBehaviour>().Range = 50f;
                    }
                }
            );
			//SC50
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("General Purpose Bomb"),
                    NameOverride = "SC50 -CWM",
                    NameToOrderByOverride = "i",
                    DescriptionOverride = "A German 55Kg Bomb.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("sc50_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("sc50.png");
						Instance.FixColliders();
                        Instance.GetComponent<ExplosiveBehaviour>().Range = 10f;
                    }
                }
            );
			//Molotov
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Handgrenade"),
                    NameOverride = "Molotov -CWM",
                    NameToOrderByOverride = "i",
                    DescriptionOverride = "A makeshift explosive filled with highly combustible fluids.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("molotov_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("molotov.png");
						Instance.GetComponent<PhysicalBehaviour>().Properties = ModAPI.FindPhysicalProperties("Glass");
                        Instance.GetComponent<ExplosiveBehaviour>().ShockwaveStrength = 0.5f;
                        Instance.GetComponent<ExplosiveBehaviour>().ShockwaveLiftForce = 0.5f;
                        Instance.GetComponent<ExplosiveBehaviour>().Range = 2f;
                        Instance.GetComponent<ExplosiveBehaviour>().BurnPower = 5f;
                        Instance.GetComponent<ExplosiveBehaviour>().ShotExplodeChance = 0.3f;
                        Instance.GetComponent<ExplosiveBehaviour>().ImpactForceThreshold = 2f;
						Instance.GetComponent<ExplosiveBehaviour>().FragmentForce = 4f;
                        Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0.20f;
                        Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.20f;
                        Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 0.20f;
						Instance.FixColliders();
                    }
                }
            );
            //Panzergranate 39 AP Shell
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Red Barrel"),
                    NameOverride = "Panzergranate 39 Shell -CWM",
					NameToOrderByOverride = "i",
                    DescriptionOverride = "A German AP shell.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("g_bigshellhe_View.png"),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("g_bigshellhe.png");
                        Instance.GetComponent<ExplosiveBehaviour>().ImpactForceThreshold = 4f;
                        Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0.80f;
                        Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.80f;
                        Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 0.80f;
                        Instance.GetComponent<ExplosiveBehaviour>().FragmentForce = 15f;
                        Instance.GetComponent<ExplosiveBehaviour>().ArmOnUse = true;
                        Instance.GetComponent<ExplosiveBehaviour>().FragmentationRayCount = 100;
                        Instance.GetComponent<ExplosiveBehaviour>().Range = 1f;
                        Instance.GetComponent<ExplosiveBehaviour>().Delay = 6f;
                        Instance.GetComponent<ExplosiveBehaviour>().BigExplosion = true;
                        Instance.GetComponent<ExplosiveBehaviour>().ShockwaveStrength = 50;
                        Instance.GetComponent<ExplosiveBehaviour>().ShockwaveLiftForce = 20f;
                        Instance.GetComponent<ExplosiveBehaviour>().BurnPower = -1f;
                        Instance.GetComponent<ExplosiveBehaviour>().ShotExplodeChance = 0.1f;
                        Instance.GetComponent<ExplosiveBehaviour>().DismemberChance = 0.5f;
                        Instance.FixColliders();
                    }
                }
            );
            //Granatwerfer 34 Mortar Shell
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Red Barrel"),
                    NameOverride = "Granatwerfer 34 Mortar Shell -CWM",
					NameToOrderByOverride = "i",
                    DescriptionOverride = "A German HE mortar shell.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("g_mshellhe_View.png"),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("g_mshellhe.png");
                        Instance.GetComponent<ExplosiveBehaviour>().ImpactForceThreshold = 4f;
                        Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0.80f;
                        Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.80f;
                        Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 0.80f;
                        Instance.GetComponent<ExplosiveBehaviour>().FragmentForce = 18f;
                        Instance.GetComponent<ExplosiveBehaviour>().ArmOnUse = true;
                        Instance.GetComponent<ExplosiveBehaviour>().FragmentationRayCount = 100;
                        Instance.GetComponent<ExplosiveBehaviour>().Range = 10f;
                        Instance.GetComponent<ExplosiveBehaviour>().Delay = 6f;
                        Instance.GetComponent<ExplosiveBehaviour>().BigExplosion = true;
                        Instance.GetComponent<ExplosiveBehaviour>().ShockwaveStrength = 50;
                        Instance.GetComponent<ExplosiveBehaviour>().ShockwaveLiftForce = 20f;
                        Instance.GetComponent<ExplosiveBehaviour>().BurnPower = -1f;
                        Instance.GetComponent<ExplosiveBehaviour>().ShotExplodeChance = 0.1f;
                        Instance.GetComponent<ExplosiveBehaviour>().DismemberChance = 0.5f;
                        Instance.FixColliders();
                    }
                }
            );
            //Panzergranate 40 AP Shell
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Red Barrel"),
                    NameOverride = "Panzergranate 40 Shell -CWM",
					NameToOrderByOverride = "i",
                    DescriptionOverride = "A German AP shell.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("g_shellhe_View.png"),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("g_shellhe.png");
                        Instance.GetComponent<ExplosiveBehaviour>().ImpactForceThreshold = 4f;
                        Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0.80f;
                        Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.80f;
                        Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 0.80f;
                        Instance.GetComponent<ExplosiveBehaviour>().FragmentForce = 12f;
                        Instance.GetComponent<ExplosiveBehaviour>().ArmOnUse = true;
                        Instance.GetComponent<ExplosiveBehaviour>().FragmentationRayCount = 100;
                        Instance.GetComponent<ExplosiveBehaviour>().Range = 1f;
                        Instance.GetComponent<ExplosiveBehaviour>().Delay = 6f;
                        Instance.GetComponent<ExplosiveBehaviour>().BigExplosion = true;
                        Instance.GetComponent<ExplosiveBehaviour>().ShockwaveStrength = 35;
                        Instance.GetComponent<ExplosiveBehaviour>().ShockwaveLiftForce = 15f;
                        Instance.GetComponent<ExplosiveBehaviour>().BurnPower = -1f;
                        Instance.GetComponent<ExplosiveBehaviour>().ShotExplodeChance = 0.1f;
                        Instance.GetComponent<ExplosiveBehaviour>().DismemberChance = 0.5f;
                        Instance.FixColliders();
                    }
                }
            );
            //M72 AP Shell
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Red Barrel"),
                    NameOverride = "M72 Shell -CWM",
					NameToOrderByOverride = "i",
                    DescriptionOverride = "An American AP shell.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("a_shellhe_View.png"),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("a_shellhe.png");
                        Instance.GetComponent<ExplosiveBehaviour>().ImpactForceThreshold = 4f;
                        Instance.GetComponent<PhysicalBehaviour>().InitialMass = 0.80f;
                        Instance.GetComponent<PhysicalBehaviour>().TrueInitialMass = 0.80f;
                        Instance.GetComponent<PhysicalBehaviour>().rigidbody.mass = 0.80f;
                        Instance.GetComponent<ExplosiveBehaviour>().FragmentForce = 12f;
                        Instance.GetComponent<ExplosiveBehaviour>().ArmOnUse = true;
                        Instance.GetComponent<ExplosiveBehaviour>().FragmentationRayCount = 100;
                        Instance.GetComponent<ExplosiveBehaviour>().Range = 1f;
                        Instance.GetComponent<ExplosiveBehaviour>().Delay = 6f;
                        Instance.GetComponent<ExplosiveBehaviour>().BigExplosion = true;
                        Instance.GetComponent<ExplosiveBehaviour>().ShockwaveStrength = 35;
                        Instance.GetComponent<ExplosiveBehaviour>().ShockwaveLiftForce = 15f;
                        Instance.GetComponent<ExplosiveBehaviour>().BurnPower = -1f;
                        Instance.GetComponent<ExplosiveBehaviour>().ShotExplodeChance = 0.1f;
                        Instance.GetComponent<ExplosiveBehaviour>().DismemberChance = 0.5f;
                        Instance.FixColliders();
                    }
                }
            );
			//Medical Bag
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Crossbow"),
                    NameOverride = "Medical Bag -CWM",
                    NameToOrderByOverride = "j",
                    DescriptionOverride = "A bag to hold all of your medical supplies, can be activated.",
                    CategoryOverride = ModAPI.FindCategory("Hazard"),
                    ThumbnailOverride = ModAPI.LoadSprite("medic_bag_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("medic_bag.png");
						Instance.FixColliders();
                        Instance.GetComponent<ProjectileLauncherBehaviour>().projectileAsset = ModAPI.FindSpawnable("Coagulation Syrette -CWM");
                        Instance.GetComponent<ProjectileLauncherBehaviour>().projectileLaunchStrength = 0f;
                    }
                }
            );
			//Coagulation Syrette
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Coagulation Syringe"),
                    NameOverride = "Coagulation Syrette -CWM",
                    NameToOrderByOverride = "j",
                    DescriptionOverride = "Contains a compound to stop bleeding.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("c_syrette_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("syrette.png");
						Instance.FixColliders();
                    }
                }
            );
			//Adrenaline Syrette
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Adrenaline Syringe"),
                    NameOverride = "Adrenaline Syrette -CWM",
                    NameToOrderByOverride = "j",
                    DescriptionOverride = "Contains a compound to increase awareness.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("a_syrette_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("syrette.png");
						Instance.FixColliders();
                    }
                }
            );
			//Knockout Syrette
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Knockout Syringe"),
                    NameOverride = "Knockout Syrette -CWM",
                    NameToOrderByOverride = "j",
                    DescriptionOverride = "Contains a compound to decrease awareness.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("k_syrette_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("syrette.png");
						Instance.FixColliders();
                    }
                }
            );
			//Pillbox
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Brick Cube"),
                    NameOverride = "Pillbox -CWM",
                    NameToOrderByOverride = "k",
                    DescriptionOverride = "An iconic WWII pillbox.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("pillbox_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("pillbox.png");
						Instance.FixColliders();
                    }
                }
            );
			//Dragon Tooth
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Brick Cube"),
                    NameOverride = "Dragon Tooth -CWM",
                    NameToOrderByOverride = "k",
                    DescriptionOverride = "A WWII anti-tank fortification.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("tooth_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("tooth.png");
						Instance.FixColliders();
                    }
                }
            );
			//German Banner
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Stick"),
                    NameOverride = "German Banner -CWM",
                    NameToOrderByOverride = "k",
                    DescriptionOverride = "A WWII German banner. PURELY FOR HISTORICAL REENACTMENT.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("s_banner_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("g_banner.png");
						Instance.GetComponent<SpriteRenderer>().sortingLayerName = "Bottom";
						Instance.FixColliders();
                    }
                }
            );
			//Soviet Banner
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Stick"),
                    NameOverride = "Soviet Banner -CWM",
                    NameToOrderByOverride = "k",
                    DescriptionOverride = "A WWII Soviet banner.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("s_banner_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("s_banner.png");
						Instance.GetComponent<SpriteRenderer>().sortingLayerName = "Bottom";
						Instance.FixColliders();
                    }
                }
            );
			//American Banner
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Stick"),
                    NameOverride = "American Banner -CWM",
                    NameToOrderByOverride = "k",
                    DescriptionOverride = "A WWII American banner.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("a_banner_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("a_banner.png");
						Instance.GetComponent<SpriteRenderer>().sortingLayerName = "Bottom";
						Instance.FixColliders();
                    }
                }
            );
			//Czech Hedgehog
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Metal Cube"),
                    NameOverride = "Czech Hedgehog -CWM",
                    NameToOrderByOverride = "k",
                    DescriptionOverride = "A WWII anti-tank fortification.",
                    CategoryOverride = ModAPI.FindCategory("World War II"),
                    ThumbnailOverride = ModAPI.LoadSprite("czech_h_View.png", 5f),
                    AfterSpawn = (Instance) =>
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("czech_h.png");
						Instance.FixColliders();
                    }
                }
            );
        }
    }
}